Get most supported rule creators
Source:R/get_most_supported_creators.R
get_most_supported_creators.RdReturns top rule creators ordered by total support count (sum of supports across all their rules).
R/get_most_supported_creators.R
get_most_supported_creators.RdReturns top rule creators ordered by total support count (sum of supports across all their rules).