Clean a GBIF download of suspicious records using complex rules
Source:R/clean_download.R
clean_download.RdRemoves records that have been marked as suspicious by annotation users using complex rules. Only filters based on SUSPICIOUS annotations, ignoring other annotation types. If project_id is provided, only rules belonging to those project(s) will be used.
Usage
clean_download(
d,
rm_suspicious = TRUE,
handle_conflicts = "favor_suspicious",
project_id = NULL
)