Reset a project's vocabulary to the default system vocabulary. Removes any custom vocabulary terms that were defined for the project.
Details
Removes the custom vocabulary from a project and reverts to the default system vocabulary. Only project members can reset vocabulary. Authentication via GBIF_USER and GBIF_PWD environment variables is required (or can be provided via user/pwd parameters).
The default vocabulary includes: NATIVE, INTRODUCED, MANAGED, FORMER, VAGRANT, SUSPICIOUS, and OTHER.